==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/hu/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ez a negyedév",
	"field-quarter-short-relative+1": "következő negyedév",
	"field-tue-relative+-1": "előző kedd",
	"field-year": "év",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "ez a szerda",
	"field-wed-relative+1": "következő szerda",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "perc",
	"field-month-narrow-relative+-1": "előző hónap",
	"field-tue-narrow-relative+0": "ez a kedd",
	"field-tue-narrow-relative+1": "következő kedd",
	"field-day-short-relative+-1": "tegnap",
	"field-thu-short-relative+0": "ez a csütörtök",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "ma",
	"field-day-short-relative+-2": "tegnapelőtt",
	"field-thu-short-relative+1": "következő csütörtök",
	"field-day-relative+1": "holnap",
	"field-week-narrow-relative+0": "ez a hét",
	"field-day-relative+2": "holnapután",
	"field-week-narrow-relative+1": "következő hét",
	"field-wed-narrow-relative+-1": "előző szerda",
	"field-year-narrow": "év",
	"field-year-narrow-relative+0": "ez az év",
	"field-tue-relative+0": "ez a kedd",
	"field-year-narrow-relative+1": "következő év",
	"field-tue-relative+1": "következő kedd",
	"field-second-short": "másodperc",
	"dateFormatItem-MMMd": "MMM d.",
	"field-week-relative+0": "ez a hét",
	"field-month-relative+0": "ez a hónap",
	"field-week-relative+1": "következő hét",
	"field-month-relative+1": "következő hónap",
	"field-sun-narrow-relative+0": "ez a vasárnap",
	"field-mon-short-relative+0": "ez a hétfő",
	"field-sun-narrow-relative+1": "következő vasárnap",
	"field-mon-short-relative+1": "következő hétfő",
	"field-second-relative+0": "most",
	"dateFormatItem-yyyyQQQ": "G y. QQQ",
	"field-month-short": "hónap",
	"dateFormatItem-GyMMMEd": "G y. MMM d., E",
	"dateFormatItem-yyyyMd": "G y. MM. dd.",
	"field-day": "nap",
	"field-year-relative+-1": "előző év",
	"field-sat-short-relative+-1": "előző szombat",
	"field-hour-relative+0": "ebben az órában",
	"dateFormatItem-yyyyMEd": "G y. MM. dd., E",
	"field-wed-relative+-1": "előző szerda",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "előző szombat",
	"field-second": "másodperc",
	"dateFormat-long": "G y. MMMM d.",
	"dateFormatItem-GyMMMd": "G y. MMM d.",
	"field-quarter": "negyedév",
	"field-week-short": "hét",
	"field-day-narrow-relative+0": "ma",
	"field-day-narrow-relative+1": "holnap",
	"field-day-narrow-relative+2": "holnapután",
	"field-tue-short-relative+0": "ez a kedd",
	"field-tue-short-relative+1": "következő kedd",
	"field-month-short-relative+-1": "előző hónap",
	"field-mon-relative+-1": "előző hétfő",
	"dateFormatItem-GyMMM": "G y. MMM",
	"field-month": "hónap",
	"field-day-narrow": "nap",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "perc",
	"field-dayperiod": "napszak",
	"field-sat-short-relative+0": "ez a szombat",
	"field-sat-short-relative+1": "következő szombat",
	"dateFormat-medium": "G y. MMM d.",
	"dateFormatItem-yyyyMMMM": "G y. MMMM",
	"dateFormatItem-yyyyM": "G y. MM.",
	"field-second-narrow": "másodperc",
	"field-mon-relative+0": "ez a hétfő",
	"field-mon-relative+1": "következő hétfő",
	"field-day-narrow-relative+-1": "tegnap",
	"field-year-short": "év",
	"field-day-narrow-relative+-2": "tegnapelőtt",
	"field-quarter-relative+-1": "előző negyedév",
	"dateFormatItem-yyyyMMMd": "G y. MMM d.",
	"field-week-narrow-relative+-1": "előző hét",
	"field-sat-relative+-1": "előző szombat",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "óra",
	"dateFormat-full": "G y. MMMM d., EEEE",
	"field-month-relative+-1": "előző hónap",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "negyedév",
	"field-sat-narrow-relative+0": "ez a szombat",
	"field-fri-relative+0": "ez a péntek",
	"field-sat-narrow-relative+1": "következő szombat",
	"field-fri-relative+1": "következő péntek",
	"field-month-narrow-relative+0": "ez a hónap",
	"field-month-narrow-relative+1": "következő hónap",
	"field-sun-short-relative+0": "ez a vasárnap",
	"field-sun-short-relative+1": "következő vasárnap",
	"field-week-relative+-1": "előző hét",
	"field-quarter-short-relative+-1": "előző negyedév",
	"field-quarter-relative+0": "ez a negyedév",
	"field-minute-relative+0": "ebben a percben",
	"field-quarter-relative+1": "következő negyedév",
	"field-wed-short-relative+-1": "előző szerda",
	"dateFormat-short": "GGGGG y. M. d.",
	"field-year-narrow-relative+-1": "előző év",
	"field-thu-short-relative+-1": "előző csütörtök",
	"dateFormatItem-yyyyMMMEd": "G y. MMM d., E",
	"field-mon-narrow-relative+-1": "előző hétfő",
	"dateFormatItem-MMMMd": "MMMM d.",
	"field-thu-narrow-relative+-1": "előző csütörtök",
	"dateFormatItem-E": "ccc",
	"field-tue-narrow-relative+-1": "előző kedd",
	"dateFormatItem-H": "H",
	"dateFormatItem-yyyy": "G y.",
	"field-wed-short-relative+0": "ez a szerda",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+1": "következő szerda",
	"field-sun-relative+-1": "előző vasárnap",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-d": "d",
	"field-weekday": "hét napja",
	"field-day-short-relative+0": "ma",
	"field-quarter-narrow-relative+0": "ez a negyedév",
	"field-day-short-relative+1": "holnap",
	"field-sat-relative+0": "ez a szombat",
	"field-quarter-narrow-relative+1": "következő negyedév",
	"dateFormatItem-h": "a h",
	"field-day-short-relative+2": "holnapután",
	"field-sat-relative+1": "következő szombat",
	"field-week-short-relative+0": "ez a hét",
	"field-week-short-relative+1": "következő hét",
	"field-month-short-relative+0": "ez a hónap",
	"field-month-short-relative+1": "következő hónap",
	"dateFormatItem-MEd": "M. d., E",
	"dateFormatItem-y": "G y.",
	"field-thu-narrow-relative+0": "ez a csütörtök",
	"field-sun-narrow-relative+-1": "előző vasárnap",
	"field-mon-short-relative+-1": "előző hétfő",
	"field-thu-narrow-relative+1": "következő csütörtök",
	"field-thu-relative+0": "ez a csütörtök",
	"field-thu-relative+1": "következő csütörtök",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-fri-short-relative+-1": "előző péntek",
	"field-thu-relative+-1": "előző csütörtök",
	"field-week": "hét",
	"dateFormatItem-Ed": "d., E",
	"field-wed-narrow-relative+0": "ez a szerda",
	"field-wed-narrow-relative+1": "következő szerda",
	"field-quarter-narrow-relative+-1": "előző negyedév",
	"field-year-short-relative+0": "ez az év",
	"dateFormatItem-yyyyMMM": "G y. MMM",
	"field-year-short-relative+1": "következő év",
	"field-fri-short-relative+0": "ez a péntek",
	"field-fri-short-relative+1": "következő péntek",
	"field-week-short-relative+-1": "előző hét",
	"dateFormatItem-yyyyQQQQ": "G y. QQQQ",
	"field-hour-short": "óra",
	"field-month-narrow": "hónap",
	"field-hour-narrow": "óra",
	"field-fri-narrow-relative+-1": "előző péntek",
	"field-year-relative+0": "ez az év",
	"field-year-relative+1": "következő év",
	"field-fri-relative+-1": "előző péntek",
	"field-tue-short-relative+-1": "előző kedd",
	"field-minute-narrow": "perc",
	"field-mon-narrow-relative+0": "ez a hétfő",
	"field-mon-narrow-relative+1": "következő hétfő",
	"field-year-short-relative+-1": "előző év",
	"field-zone": "időzóna",
	"dateFormatItem-MMMEd": "MMM d., E",
	"field-quarter-narrow": "negyedév",
	"field-sun-short-relative+-1": "előző vasárnap",
	"field-day-relative+-1": "tegnap",
	"field-day-relative+-2": "tegnapelőtt",
	"field-sun-relative+0": "ez a vasárnap",
	"field-sun-relative+1": "következő vasárnap",
	"dateFormatItem-Gy": "G y.",
	"field-day-short": "nap",
	"field-week-narrow": "hét",
	"field-era": "éra",
	"field-fri-narrow-relative+0": "ez a péntek",
	"field-fri-narrow-relative+1": "következő péntek"
}
//end v1.x content
);

==> dojo_1.17.3+dfsg1.orig.tar.xz: dojo-release-1.17.3-src/dojo/cldr/nls/hu/generic.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "ez a negyedév",
	"field-quarter-short-relative+1": "következő negyedév",
	"field-tue-relative+-1": "előző kedd",
	"field-year": "év",
	"dateFormatItem-Hm": "H:mm",
	"field-wed-relative+0": "ez a szerda",
	"field-wed-relative+1": "következő szerda",
	"dateFormatItem-ms": "mm:ss",
	"field-minute": "perc",
	"field-month-narrow-relative+-1": "előző hónap",
	"field-tue-narrow-relative+0": "ez a kedd",
	"field-tue-narrow-relative+1": "következő kedd",
	"field-day-short-relative+-1": "tegnap",
	"field-thu-short-relative+0": "ez a csütörtök",
	"dateTimeFormat-short": "{1} {0}",
	"field-day-relative+0": "ma",
	"field-day-short-relative+-2": "tegnapelőtt",
	"field-thu-short-relative+1": "következő csütörtök",
	"field-day-relative+1": "holnap",
	"field-week-narrow-relative+0": "ez a hét",
	"field-day-relative+2": "holnapután",
	"field-week-narrow-relative+1": "következő hét",
	"dateFormatItem-EBhms": "E h:mm:ss",
	"field-wed-narrow-relative+-1": "előző szerda",
	"field-year-narrow": "év",
	"field-era-short": "éra",
	"field-year-narrow-relative+0": "ez az év",
	"field-tue-relative+0": "ez a kedd",
	"field-year-narrow-relative+1": "következő év",
	"field-tue-relative+1": "következő kedd",
	"field-weekdayOfMonth": "hónap hétköznapja",
	"field-second-short": "másodperc",
	"dateFormatItem-MMMd": "MMM d.",
	"field-weekdayOfMonth-narrow": "hónap hétköznapja",
	"field-week-relative+0": "ez a hét",
	"field-month-relative+0": "ez a hónap",
	"field-week-relative+1": "következő hét",
	"field-month-relative+1": "következő hónap",
	"field-sun-narrow-relative+0": "ez a vasárnap",
	"field-mon-short-relative+0": "ez a hétfő",
	"field-sun-narrow-relative+1": "következő vasárnap",
	"field-mon-short-relative+1": "következő hétfő",
	"field-second-relative+0": "most",
	"dateFormatItem-yyyyQQQ": "G y. QQQ",
	"field-weekOfMonth": "hónap hete",
	"field-month-short": "hónap",
	"dateFormatItem-GyMMMEd": "G y. MMM d., E",
	"dateFormatItem-yyyyMd": "G y. MM. dd.",
	"field-day": "nap",
	"field-dayOfYear-short": "év napja",
	"field-year-relative+-1": "előző év",
	"field-sat-short-relative+-1": "előző szombat",
	"field-hour-relative+0": "ebben az órában",
	"dateFormatItem-yyyyMEd": "G y. MM. dd., E",
	"field-wed-relative+-1": "előző szerda",
	"dateTimeFormat-medium": "{1} {0}",
	"field-sat-narrow-relative+-1": "előző szombat",
	"field-second": "másodperc",
	"dateFormatItem-Ehms": "E h:mm:ss",
	"dateFormat-long": "G y. MMMM d.",
	"dateFormatItem-GyMMMd": "G y. MMM d.",
	"field-quarter": "negyedév",
	"field-week-short": "hét",
	"field-day-narrow-relative+0": "ma",
	"field-day-narrow-relative+1": "holnap",
	"field-day-narrow-relative+2": "holnapután",
	"field-tue-short-relative+0": "ez a kedd",
	"field-tue-short-relative+1": "következő kedd",
	"field-month-short-relative+-1": "előző hónap",
	"field-mon-relative+-1": "előző hétfő",
	"dateFormatItem-GyMMM": "G y. MMM",
	"field-month": "hónap",
	"field-day-narrow": "nap",
	"dateFormatItem-MMM": "LLL",
	"field-minute-short": "perc",
	"field-dayperiod": "napszak",
	"field-sat-short-relative+0": "ez a szombat",
	"field-sat-short-relative+1": "következő szombat",
	"dateFormat-medium": "G y. MMM d.",
	"dateFormatItem-yyyyMMMM": "G y. MMMM",
	"dateFormatItem-yyyyM": "G y. MM.",
	"field-second-narrow": "mp",
	"field-mon-relative+0": "ez a hétfő",
	"field-mon-relative+1": "következő hétfő",
	"field-day-narrow-relative+-1": "tegnap",
	"field-year-short": "év",
	"field-day-narrow-relative+-2": "tegnapelőtt",
	"field-quarter-relative+-1": "előző negyedév",
	"dateFormatItem-yyyyMMMd": "G y. MMM d.",
	"field-dayperiod-narrow": "napszak",
	"field-week-narrow-relative+-1": "előző hét",
	"field-dayOfYear": "év napja",
	"field-sat-relative+-1": "előző szombat",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-Md": "M. d.",
	"field-hour": "óra",
	"dateFormat-full": "G y. MMMM d., EEEE",
	"field-month-relative+-1": "előző hónap",
	"dateFormatItem-Hms": "H:mm:ss",
	"field-quarter-short": "n.év",
	"field-sat-narrow-relative+0": "ez a szombat",
	"field-fri-relative+0": "ez a péntek",
	"field-sat-narrow-relative+1": "következő szombat",
	"field-fri-relative+1": "következő péntek",
	"dateFormatItem-EBhm": "E h:mm",
	"field-month-narrow-relative+0": "ez a hónap",
	"field-month-narrow-relative+1": "következő hónap",
	"field-sun-short-relative+0": "ez a vasárnap",
	"field-sun-short-relative+1": "következő vasárnap",
	"field-week-relative+-1": "előző hét",
	"field-quarter-short-relative+-1": "előző negyedév",
	"dateFormatItem-Ehm": "E h:mm",
	"field-quarter-relative+0": "ez a negyedév",
	"field-minute-relative+0": "ebben a percben",
	"field-quarter-relative+1": "következő negyedév",
	"field-wed-short-relative+-1": "előző szerda",
	"dateFormat-short": "GGGGG y. M. d.",
	"dateFormatItem-Bh": "B h",
	"field-year-narrow-relative+-1": "előző év",
	"field-thu-short-relative+-1": "előző csütörtök",
	"dateFormatItem-yyyyMMMEd": "G y. MMM d., E",
	"field-mon-narrow-relative+-1": "előző hétfő",
	"dateFormatItem-MMMMd": "MMMM d.",
	"field-thu-narrow-relative+-1": "előző csütörtök",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-H": "H",
	"field-weekOfMonth-short": "hónap hete",
	"field-tue-narrow-relative+-1": "előző kedd",
	"dateFormatItem-yyyy": "G y.",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "ez a szerda",
	"field-wed-short-relative+1": "következő szerda",
	"field-sun-relative+-1": "előző vasárnap",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-hm": "a h:mm",
	"dateFormatItem-d": "d",
	"field-weekday": "hét napja",
	"field-day-short-relative+0": "ma",
	"field-quarter-narrow-relative+0": "ez a negyedév",
	"field-day-short-relative+1": "holnap",
	"field-sat-relative+0": "ez a szombat",
	"field-quarter-narrow-relative+1": "következő negyedév",
	"dateFormatItem-h": "a h",
	"field-day-short-relative+2": "holnapután",
	"field-sat-relative+1": "következő szombat",
	"field-week-short-relative+0": "ez a hét",
	"field-week-short-relative+1": "következő hét",
	"field-dayOfYear-narrow": "év napja",
	"field-month-short-relative+0": "ez a hónap",
	"field-month-short-relative+1": "következő hónap",
	"field-weekdayOfMonth-short": "hónap hétköznapja",
	"dateFormatItem-MEd": "M. d., E",
	"field-zone-narrow": "időzóna",
	"dateFormatItem-y": "G y.",
	"field-thu-narrow-relative+0": "ez a csütörtök",
	"field-sun-narrow-relative+-1": "előző vasárnap",
	"field-mon-short-relative+-1": "előző hétfő",
	"field-thu-narrow-relative+1": "következő csütörtök",
	"field-thu-relative+0": "ez a csütörtök",
	"field-thu-relative+1": "következő csütörtök",
	"dateFormatItem-hms": "a h:mm:ss",
	"field-fri-short-relative+-1": "előző péntek",
	"field-thu-relative+-1": "előző csütörtök",
	"field-week": "hét",
	"dateFormatItem-Ed": "d., E",
	"field-wed-narrow-relative+0": "ez a szerda",
	"field-wed-narrow-relative+1": "következő szerda",
	"field-quarter-narrow-relative+-1": "előző negyedév",
	"field-year-short-relative+0": "ez az év",
	"dateFormatItem-yyyyMMM": "G y. MMM",
	"field-dayperiod-short": "napszak",
	"field-year-short-relative+1": "következő év",
	"field-fri-short-relative+0": "ez a péntek",
	"field-fri-short-relative+1": "következő péntek",
	"field-week-short-relative+-1": "előző hét",
	"dateFormatItem-yyyyQQQQ": "G y. QQQQ",
	"field-hour-short": "óra",
	"field-zone-short": "időzóna",
	"field-month-narrow": "hónap",
	"field-hour-narrow": "ó",
	"field-fri-narrow-relative+-1": "előző péntek",
	"field-year-relative+0": "ez az év",
	"field-year-relative+1": "következő év",
	"field-era-narrow": "éra",
	"field-fri-relative+-1": "előző péntek",
	"dateFormatItem-Bhms": "B h:mm:ss",
	"field-tue-short-relative+-1": "előző kedd",
	"field-minute-narrow": "p",
	"field-mon-narrow-relative+0": "ez a hétfő",
	"dateFormatItem-EHm": "E HH:mm",
	"field-mon-narrow-relative+1": "következő hétfő",
	"field-year-short-relative+-1": "előző év",
	"field-zone": "időzóna",
	"dateFormatItem-MMMEd": "MMM d., E",
	"field-weekOfMonth-narrow": "hónap hete",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"field-weekday-narrow": "hét napja",
	"field-quarter-narrow": "n.év",
	"field-sun-short-relative+-1": "előző vasárnap",
	"field-day-relative+-1": "tegnap",
	"field-day-relative+-2": "tegnapelőtt",
	"field-weekday-short": "hét napja",
	"dateFormatItem-Bhm": "B h:mm",
	"field-sun-relative+0": "ez a vasárnap",
	"field-sun-relative+1": "következő vasárnap",
	"dateFormatItem-Gy": "G y.",
	"field-day-short": "nap",
	"field-week-narrow": "hét",
	"field-era": "éra",
	"field-fri-narrow-relative+0": "ez a péntek",
	"field-fri-narrow-relative+1": "következő péntek"
}
//end v1.x content
);
